@@ -4,7 +4,8 @@ from fastapi.responses import JSONResponse
 from pydantic.dataclasses import dataclass
 
 from erdb.table import Table
-from erdb.app_api.common import GameVersionEnum, generate, as_str
+from erdb.app_api.common import DataProxy, GameVersionEnum
+from erdb.utils.common import getattrstr
 from erdb.typing.api_version import ApiVersion
 
 
@@ -13,10 +14,12 @@ class _Detail:
     detail: str
 
 class DataEndpoint:
+    data_proxy: DataProxy
     api: ApiVersion
     table: Table
 
-    def __init__(self, api: ApiVersion, table: Table) -> None:
+    def __init__(self, data_proxy: DataProxy, api: ApiVersion, table: Table) -> None:
+        self.data_proxy = data_proxy
         self.api = api
         self.table = table
 
@@ -50,7 +53,7 @@ class DataEndpoint:
         keys: list[str] | None = Query(None, alias="k", description="Specify a list of keys (ascii names) to retrieve specific items."),
         query: str | None = Query(None, description="Filter elements by field in format \"{field}:{value}\".", regex=r"^\w+\:.+$"),
     ) -> Any:
-        data = generate(self.api, game_version, self.table)
+        data = self.data_proxy.generate(self.api, game_version, self.table)
 
         if keys is not None:
             data = {k: v for k, v in data.items() if k in keys}
@@ -59,7 +62,7 @@ class DataEndpoint:
             field, value = query.split(":", maxsplit=1)
 
             try:
-                data = {k: v for k, v in data.items() if as_str(v, field) == value}
+                data = {k: v for k, v in data.items() if getattrstr(v, field) == value}
             
             except AttributeError:
                 return JSONResponse(status_code=status.HTTP_400_BAD_REQUEST, content={"detail": f"{self.table.title} has no field: \"{field}\"."})
@@ -67,10 +70,12 @@ class DataEndpoint:
         return data
 
 class ItemEndpoint:
+    data_proxy: DataProxy
     api: ApiVersion
     table: Table
 
-    def __init__(self, api: ApiVersion, table: Table) -> None:
+    def __init__(self, data_proxy: DataProxy, api: ApiVersion, table: Table) -> None:
+        self.data_proxy = data_proxy
         self.api = api
         self.table = table
 
@@ -98,7 +103,7 @@ class ItemEndpoint:
 
     def __call__(self, game_version: GameVersionEnum, key: str) -> Any:
         try:
-            return generate(self.api, game_version, self.table)[key]
+            return self.data_proxy.generate(self.api, game_version, self.table)[key]
 
         except KeyError:
             return JSONResponse(status_code=status.HTTP_404_NOT_FOUND, content={"detail": f"{self.table.title} has no key: \"{key}\""})
\ No newline at end of file
