@@ -1,4 +1,5 @@
 import re
+from enum import Enum
 from operator import add
 from itertools import repeat
 from pathlib import Path
@@ -58,4 +59,10 @@ def pydantic_encoder_no_nulls(obj: Any) -> Any:
     return remove_nulls(pydantic_encoder(obj))
 
 def get_filename(name: str) -> str:
-    return re.sub(r"(?u)[^-\w. &\[\]']", "", name)
\ No newline at end of file
+    return re.sub(r"(?u)[^-\w. &\[\]']", "", name)
+
+def as_str(v: Any) -> str:
+    return v.value if isinstance(v, Enum) else str(v)
+
+def getattrstr(obj: Any, field: str) -> str:
+    return as_str(getattr(obj, field))
\ No newline at end of file
